@@ -1,4 +1,10 @@
-/* -*- mode: c++; tab-width: 2; indent-tabs-mode: nil; -*-
+
+// NOTE: This copy of tinythread has been modified, primarily to ensure
+// compatibility with the CRAN requirements for R packages. In particular, in
+// places where tinythread would normally assert() and exit the process,
+// reticulate chooses to instead emit an R error.
+
+/*
 Copyright (c) 2010-2012 Marcus Geelnard
 
 This software is provided 'as-is', without any express or implied
@@ -24,6 +30,8 @@ freely, subject to the following restrictions:
 #ifndef _TINYTHREAD_H_
 #define _TINYTHREAD_H_
 
+extern "C" void Rf_error(const char* fmt, ...);
+
 /// @file
 /// @mainpage TinyThread++ API Reference
 ///
@@ -865,7 +873,7 @@ inline void * thread::wrapper_function(void * aArg)
   {
     // Uncaught exceptions will terminate the application (default behavior
     // according to C++11)
-    std::terminate();
+    Rf_error("[reticulate] Internal error: exception in %s\n", __func__);
   }
 
   // The thread is no longer executing
@@ -911,8 +919,8 @@ inline thread::thread(void (*aFunction)(void *), void * aArg)
 
 inline thread::~thread()
 {
-  if(joinable())
-    std::terminate();
+  if (joinable())
+    Rf_error("[reticulate] Internal error: destructor called on joinable thread.\n");
 }
 
 inline void thread::join()
